/* global Drupal */

// Ensure $ is available: Foundation and select2 need to bind to it
import $ from 'jquery'
import select2 from 'select2'

import { Accordion, Foundation, Reveal, SmoothScroll, Toggler } from 'foundation-sites/js/foundation'
import { SelectTwo, AdaptiveSticky, CookieBar, FileUpload, StickyButton, ToggleElement } from '@moreonion/foundation-base'
import { storageAvailable } from '@moreonion/js-utils/src/utils'

// Add the select2 to jQuery
// Needed for SelectTwo plugin
select2($)

// Add Foundation to jQuery
Foundation.addToJquery($)

// Configure Foundation
Foundation.plugin(ToggleElement, 'ToggleElement')
Foundation.plugin(SelectTwo, 'SelectTwo')
Foundation.plugin(AdaptiveSticky, 'AdaptiveSticky')
Foundation.plugin(CookieBar, 'CookieBar')
Foundation.plugin(FileUpload, 'FileUpload')
Foundation.plugin(StickyButton, 'StickyButton')

// Let foundation initialize the initial markup
// This needs to be done for dynamically loaded markup too (e.g. AJAX markup)
export function initFoundation () {
  if (typeof Drupal !== 'undefined') {
    Drupal.behaviors.foundist_initialize = {}
    Drupal.behaviors.foundist_initialize.attach = (context, settings) => {
      $(context).foundation()
      // Show overlays with `data-open` initially.
      const $overlay = $('[data-reveal][data-open]')
      if (context === document && $overlay.length) {
        $overlay.foundation('open')
      }
    }
  } else {
    $(window.document).foundation()
  }
}

// Activate AdaptiveSticky on forms in the sidebar.
export function stickyForm () {
  const $form = $('#sidebar form, #sidebar .share-buttons')
  if (!$form.length) {
    return
  }
  const $sidebar = $('#sidebar')
  // Add a wrapper around the #sidebar content to make all of it sticky.
  $sidebar.children().wrapAll('<div class="sticky" />')
  // Let the actual form inside #form stick to the window top.
  return new Foundation.AdaptiveSticky($sidebar.children('.sticky'), {
    target: '#form-outer form, #form-outer .share-buttons ul',
    offset: $('#form-outer').css('padding-top'),
    mediaQuery: 'large'
  })
}

// Activate StickyButton on CTA markup snippet.
export function stickyButton () {
  let $cta = $('.sticky-cta')
  if (!$cta.length) {
    return
  }
  // Put button(s) in right position.
  // Depending on the layout, the button should be on the bottom of the page,
  // the sidebar or the main wrapper for large screen sizes.
  const target = $cta.find('a').attr('href')
  const $newParent = $('#sidebar, #main > .grid-container > .inner-wrapper')
  if ($newParent.length) {
    const $clone = $cta.clone().appendTo($newParent).addClass('bottom show-for-large')
    $cta.appendTo('#page').addClass('bottom hide-for-large')
    $cta = $cta.add($clone)
  } else {
    $cta.appendTo('#page').addClass('bottom')
  }
  // Add SmoothScroll
  const scroll = new SmoothScroll($cta.find('a'))
  // Initialize plugin
  return $cta.map((i, el) => {
    return new Foundation.StickyButton($(el), {
      blocker: target,
      topOverlap: 0.3
    })
  })
}

// Activate cookiebar on cookiebar id.
export function cookiebar () {
  const $cookiebar = $('#cookiebar')
  if (!$cookiebar.length) {
    return
  }
  // Put cookiebar in right position.
  $cookiebar.detach().appendTo('body')
  // Initialize plugin
  return new Foundation.CookieBar($cookiebar)
}
